@@ -32,12 +32,14 @@ if PY2:
     from cStringIO import StringIO
     iteritems = lambda d: d.iteritems() # not dict.iteritems!!! we support ordered dicts as well
     itervalues = lambda d: d.itervalues()
+    from itertools import imap as map
     from itertools import izip as zip
     from itertools import izip_longest
     xrange = _builtins.xrange
 else:
     from io import StringIO
     zip = _builtins.zip
+    map = _builtins.map
     xrange = range
     iteritems = lambda d: iter(d.items()) # not dict.items!!! See above
     itervalues = lambda d: iter(d.values())
