@@ -1,12 +1,15 @@
-from contextlib import contextmanager
 import sys
+from contextlib import contextmanager
+
 from . import hooks as trigger_hook
-from .loader import Loader
-from .core.session import Session
 from . import site
+from .core.session import Session
+from .conf import config
+from .loader import Loader
+from .reporting.console_reporter import ConsoleReporter
 from .utils import cli_utils
 from .utils.interactive import start_interactive_shell
-from .utils.reporter import report_context
+
 
 class Application(object):
     def __init__(self, parser, args, report_stream):
@@ -15,7 +18,7 @@ class Application(object):
         self.args = args
         self.report_stream = report_stream
         self.test_loader = Loader()
-        self.session = Session()
+        self.session = Session(reporter=ConsoleReporter(level=config.root.log.console_level, stream=report_stream))
     def error(self, *args, **kwargs):
         self.parser.error(*args, **kwargs)
 
@@ -31,12 +34,11 @@ def get_application_context(parser=None, argv=None, args=(), report_stream=sys.s
     with cli_utils.get_cli_environment_context(argv=argv, extra_args=args, positionals_metavar=positionals_metavar) as (parser, parsed_args):
         app = Application(parser=parser, args=parsed_args, report_stream=report_stream)
         with app.session:
-            with report_context(app.report_stream):
-                _check_unknown_switches(app)
-                if enable_interactive and parsed_args.interactive:
-                    start_interactive_shell()
-                yield app
-            trigger_hook.result_summary()
+            _check_unknown_switches(app)
+            if enable_interactive and parsed_args.interactive:
+                start_interactive_shell()
+            yield app
+            trigger_hook.result_summary()  # pylint: disable=no-member
 
 def _check_unknown_switches(app):
     unknown = [arg for arg in app.args.positionals if arg.startswith("-")]
