@@ -13,6 +13,7 @@ from .exceptions import NoActiveSession, SkipTest, TestFailed
 from .metadata import ensure_test_metadata
 from .test_context import get_test_context_setup
 from .utils.iteration import PeekableIterator
+from .core.error import Error, DetailedTraceback
 
 _logger = logbook.Logger(__name__)
 
@@ -142,12 +143,13 @@ def _set_current_test_context(test):
 @contextmanager
 def _update_result_context():
     result = context.session.results.create_result(context.test)
+    result.set_log_path(context.session.logging.test_log_path)
     result.mark_started()
     try:
         try:
             yield result
         except:
-            _logger.debug("Exception escaped test", exc_info=sys.exc_info())
+            _logger.debug("Exception escaped test:\n{0}", DetailedTraceback(Error.capture_exception()))
             raise
     except SkipTest as e:
         result.add_skip(e.reason)
