@@ -1,17 +1,19 @@
-from .utils import TestCase
+import gossip
 import slash
 import slash.runner
-from slash import exception_handling
-from slash import Session
+from slash import exception_handling, Session
 from slash.loader import Loader
 
+from .utils import TestCase
+
+
 class CleanupsTest(TestCase):
 
     def setUp(self):
         super(CleanupsTest, self).setUp()
         self._successful_tests = []
-        self.addCleanup(slash.hooks.test_success.unregister_by_identifier, "monitor_test_success")
-        slash.hooks.test_success.register(self._register_test_success, "monitor_test_success")
+        self.addCleanup(gossip.unregister_token, "monitor_test_success")
+        slash.hooks.test_success.register(self._register_test_success, token="monitor_test_success")
 
     def _register_test_success(self):
         self._successful_tests.append(slash.context.test)
@@ -37,7 +39,7 @@ class CleanupsTest(TestCase):
 
         self.forge.replay()
         with Session():
-            slash.runner.run_tests(Loader().iter_test_factory(Test))
+            slash.runner.run_tests(Loader().get_runnables(Test))
 
         assert len(self._successful_tests) == 2
 
@@ -64,11 +66,12 @@ class CleanupsTest(TestCase):
         self.events.cleanup(1).and_raise(FirstException())
         self.forge.replay()
         with Session() as session:
-            slash.runner.run_tests(Loader().iter_test_factory(Test))
+            slash.runner.run_tests(Loader().get_runnables(Test))
+        self.forge.verify()
         [result] = session.results.iter_test_results()
         errors = result.get_errors()
 
-        assert len(errors) == 3 if fail_test else 2
+        assert len(errors) == (3 if fail_test else 2)
 
         self.assertEquals(len(errors), len(exc_infos))
         self.assertEquals(
